c ***************************************************************************
c     mrrfge
c ***************************************************************************
c
      subroutine mrrfge(jtype,xr)
c
c     This subroutine read in the geometries from the esp.fu71 to esp.fu78
c     input files.
c     (Titus V Albu February 2002)
c
      implicit double precision (a-h,o-z)
c
      include 'mcparm.inc'
      include 'mcperc.inc'
      include 'mccomm.inc'
      include 'mcrate.inc'
c
      dimension xr(mcmcar,8)
      dimension xii(mcmcar)
c
      character*20 finame
      character*7  fistat
      character*20 fstat
      character*80 word(40)
c
      logical lexit
c
c     Initialize some variables
c
      iunitr = 70+jtype
c
      do i=1,mcmcar
         xii(i)=0.d0
      enddo
c
c     Open the input file
c
      lexit  = .false.
      fistat = 'old'
      finame = 'esp.fu7 '
      finame(8:8)=char(48+jtype)
c
      call mcfope (iunitr, fistat, finame, lexit)
      if (lexit) then
         write (fu6,100) iunitr
         stop 'mrrfge 1'
      endif
 100  format (1x,'Error opening the input file esp.fu',i2,'.')
c
c     Read the number of points in the input file
c
      call mcrlnw(iunitr,word,nword)
      if (word(1).eq.'POINTS') then
         if (nword.ge.2) then
            npoint = cfmct(word(2))
         else
            write (fu6,1000)
            stop 'mrrfge 1'
         endif
      else
         write (fu6,2000) iunitr
         stop 'mrrfge 2'
      endif
c
c     Read the format of the input file
c
      call mcrlnw(iunitr,word,nword)
      if (word(1).eq.'FORMAT') then
         if (nword.ge.2) then
            mcifrm = cfmct(word(2))
         else
            write (fu6,3000)
            stop 'mrrfge 3'
         endif
      else
         write (fu6,4000) iunitr
         stop 'mrrfge 4'
      endif
c
c     Check if the number of points is equal to 1
c
      if (npoint.ne.1) then
         write (fu6,5000) iunitr
         stop 'mrrfge 5'
      endif
c
c     Check if the format of the input is allowed
c
      if (mcifrm.lt.1.or.mcifrm.gt.3) then
         write (fu6,6000) iunitr
         stop 'mrrfge 6'
      endif
 1000 format(1x,'Error: POINTS keyword should have an argument.')
 2000 format(1x,'Error: POINTS keyword should be on the first ',
     *          'line of the esp.fu',i2,' input file.')
 3000 format(1x,'Error: FORMAT keyword should have an argument.')
 4000 format(1x,'Error: FORMAT keyword should be on the second ',
     *          'line of the esp.fu',i2,' input file.')
 5000 format(1x,'Error: Wrong number of geometries in fu',i2,
     *          ' input file.')
 6000 format(1x,'Error: The format of the esp.fu',i2,' input file ',
     *          'is not allowed.')
c
c     Read the geometry:
c     mcifrm = 1: one line with the number of atoms
c                 one comment line
c                 mcnatm lines with one atom index and three coordinates
c     mcifrm = 2: one comment line
c                 mcnatm lines with one atom index and three coordinates
c     mcifrm = 3: one comment line
c                 mcnatm lines with three coordinates
c
      if (mcifrm.eq.1) then
         call mcrlnw(iunitr,word,nword)
         if (nword.ge.1) noatms = cfmct(word(1))
         if (noatms.ne.mrnatm(jtype)) then
            write (fu6,7000)
            stop 'mrrfge 7'
         endif
         call mcrlnw(iunitr,word,nword)
         do i=1,mrnatm(jtype)
            call mcrlnw(iunitr,word,nword)
            if (nword.lt.4) then
               write (fu6,8000)
               stop 'mrrfge 8'
            else
               xii(3*i-2) = cfmct(word(2))
               xii(3*i-1) = cfmct(word(3))
               xii(3*i) = cfmct(word(4))
            endif
         enddo
      elseif (mcifrm.eq.2) then
         call mcrlnw(iunitr,word,nword)
         do i=1,mrnatm(jtype)
            call mcrlnw(iunitr,word,nword)
            if (nword.lt.4) then
               write (fu6,8000)
               stop 'mrrfge 9'
            else
               xii(3*i-2) = cfmct(word(2))
               xii(3*i-1) = cfmct(word(3))
               xii(3*i) = cfmct(word(4))
            endif
         enddo
      elseif (mcifrm.eq.3) then
         call mcrlnw(iunitr,word,nword)
         do i=1,mrnatm(jtype)
            call mcrlnw(iunitr,word,nword)
            if (nword.lt.3) then
               write (fu6,8000)
               stop 'mrrfge 10'
            else
               xii(3*i-2) = cfmct(word(1))
               xii(3*i-1) = cfmct(word(2))
               xii(3*i) = cfmct(word(3))
            endif
         enddo
      endif
 7000 format(1x,'Error in the number of atoms in esp.fu',i2,'.')
 8000 format(1x,'Error in reading geometries in esp.fu',i2,'.')

c
c     Transform the geometry to bohr
c
      if (mriufi(jtype).eq.3) then
         do i=1,3*mrnatm(jtype)
            xii(i)=xii(i)/fboan
         enddo
      endif
c
c     Put the geometry in its right place in the geometry array xr
c
      do j=1,mcmatm
         do k=1,mrnatm(jtype)
            if (j.eq.miatsv(k,jtype)) then
               if (jtype.eq.1.or.jtype.eq.2) then
                  xr(3*j-2,1) = xii(3*k-2)
                  xr(3*j-1,1) = xii(3*k-1)
                  xr(3*j,1) = xii(3*k)
               elseif (jtype.eq.3.or.jtype.eq.4) then
                  xr(3*j-2,3) = xii(3*k-2)
                  xr(3*j-1,3) = xii(3*k-1)
                  xr(3*j,3) = xii(3*k)
               elseif (jtype.ge.5) then
                  xr(3*j-2,jtype) = xii(3*k-2)
                  xr(3*j-1,jtype) = xii(3*k-1)
                  xr(3*j,jtype) = xii(3*k)
               endif
            endif
         enddo
      enddo
c
c
      return
      end
c ***************************************************************************
c     mrrfao
c ***************************************************************************

      subroutine mrrfao
c
c     Subroutine to read in the esp.fu70 input file with additional
c     information used only for MC-TINKERATE.
c     (Titus V Albu February 2002)
c
      implicit double precision (a-h,o-z)
c
      include 'mcparm.inc'
      include 'mcperc.inc'
      include 'mccomm.inc'
      include 'mcrate.inc'
c
      character * 80 string
      character * 20 finame
      character *  7 fistat
      character * 20 fstat
      logical lexit
      logical exist
c
c     Set the default value for the keywords
c
      call mrsdef
c
c     If it exists, open and read esp.fu70
c
      inquire (file="esp.fu70",exist=exist)
      if (exist) then
         lexit  = .false.
         fistat = 'old'
         finame = 'esp.fu70'
         call mcfope (fu70, fistat, finame, lexit)
         if (lexit) then
            write (fu6,100)
            stop 'mrrfao 1'
         endif
c
c     Start off by finding the first section given in the input deck
c
         call mcrlin(fu70,string,istrt,isect,iend)
c
c     Check that the file wasn't empty and that the first line found was
c     the start of a section
c
         if (iend.eq.1) then
            write(fu6,1000)
            stop 'mrrfao 2'
         end if
         if (isect.ne.1) then
            write(fu6,1100)
            stop 'mrrfao 3'
         end if
c
c     Call the routine to read the type of calculation in each section.  
c
         do while (iend.eq.0)
            j = istrt + 1
c
c  MRREACT1 section
c
            if (string(j:j+7).eq.'mrreact1') then
               call mrrsta(string,iend,istrt,1)
c
c  MRREACT2 section
c
            else if (string(j:j+7).eq.'mrreact2') then
               call mrrsta(string,iend,istrt,2)
c
c  MRPROD1 section
c
            else if (string(j:j+6).eq.'mrprod1') then
               call mrrsta(string,iend,istrt,3)
c
c  MRPROD2 section
c
            else if (string(j:j+6).eq.'mrprod2') then
               call mrrsta(string,iend,istrt,4)
c
c  MRSTART section
c
            else if (string(j:j+6).eq.'mrstart') then
               call mrrsta(string,iend,istrt,5)
               mriord(6) = mriord(5)
               mriufi(6) = mriufi(5)
c
c  MRWELLR section
c
            else if (string(j:j+6).eq.'mrwellr') then
               call mrrsta(string,iend,istrt,7)
c
c  MRWELLP section
c
            else if (string(j:j+6).eq.'mrwellp') then
               call mrrsta(string,iend,istrt,8)
c
            else
               write(fu6,1200) string(j-1:80)
               stop 'mrrfao 4'
            end if
         end do
c
c     Close the input files esp.fu70
c
         fstat = 'keep'
         call mcfclo (fu70,fstat)
      endif
c
 100  format(1x,'Error opening the esp.fu70 input file')
 1000 format(1x,'Error: the esp.fu70 input file is empty')
 1100 format(1x,'Error: first non-comment, non-blank line in the ',
     *          'esp.fu70 input file must be',
     *      /1x,'a section header that begins with a *')
 1200 format(1x,'Error: the following is not a valid section ',
     *          'name in esp.fu70',/A80/)
c
c
      return
      end
c ***************************************************************************
c     mrrsta
c ***************************************************************************

      subroutine mrrsta(string,iend,istrt,jtype)
c
c     Subroutine to read in the keywords for MC-TINKERATE.
c     Jtype = 1  first reactant
c     Jtype = 2  second reactant
c     Jtype = 3  first product
c     Jtype = 4  second product
c     Jtype = 5  saddle point or starting stationary point
c     Jtype = 7  reactant well
c     Jtype = 8  product well
c     (Titus V Albu February 2002)
c
      implicit double precision (a-h,o-z)
c
      include 'mcparm.inc'
      include 'mcperc.inc'
      include 'mccomm.inc'
      include 'mcrate.inc'
c
      character * 80 string
c
c     Finding the first keyword
c
      call mcrlin(fu70,string,istrt,isect,iend)
c
      do while (isect.eq.0.and.iend.eq.0)
c
c     MRUNITINPUT
c
        if (string(istrt:istrt+10).eq.'mrunitinput') then
            call rword(string,istrt,ierr)
            if (ierr.ne.1) then
                if(string(istrt:istrt+3).eq.'bohr') then
                   mriufi(jtype) = 1
                elseif (string(istrt:istrt+2).eq.'ang') then
                   mriufi(jtype) = 3
                else
                   write (fu6,1110)
                   stop 'mrrsta 1'
                endif
            else
                write(fu6,1120)
                stop 'mrrsta 2'
            endif
 1110 format (1x,'Error: Keyword MRUNITINPUT has a wrong argument.')
 1120 format (1x,'Error: Keyword MRUNITINPUT must have an argument.')
c
c     MRORDERCALC
c
c         elseif (string(istrt:istrt+10).eq.'mrordercalc') then
c            call rword(string,istrt,ierr)
c            if (ierr.ne.1) then
c               if (string(istrt:istrt+3).eq.'mcmm') then
c                  mriord(jtype) = 0
c               elseif (string(istrt:istrt+4).eq.'scmm1') then
c                  mriord(jtype) = 1
c               elseif (string(istrt:istrt+4).eq.'scmm2') then
c                  mriord(jtype) = 2
c               else
c                  write(fu6,1310)
c                  stop 'mrrsta 3'
c               endif
c            else
c               write(fu6,1320)
c               stop 'mrrsta 4'
c            endif
 1310 format (1x,'Error: Keyword MRORDERCALC has a wrong argument.')
 1320 format (1x,'Error: Keyword MRORDERCALC must have an argument.')
c
         else
            write(fu6,2000) string(istrt:80)
            stop 'mrrsta 5'
         end if
         call mcrlin(fu70,string,istrt,isect,iend)
      end do
c
 2000 format (1x,'Error: the following is not a valid keyword in ',
     *           'the esp.fu70 input file.',/A80)
c
      return
      end
c ***************************************************************************
c     mrsdef
c ***************************************************************************

      subroutine mrsdef
c
c     Subroutine to set the defaults for the keywords read in the esp.fu70 
c     input file.
c     (Titus V Albu February 2002)
c
      implicit double precision (a-h,o-z)
c
      include 'mcparm.inc'
      include 'mcperc.inc'
      include 'mccomm.inc'
      include 'mcrate.inc'
c
c     Type of calculation
c
      mriord(1) = 1
      mriord(2) = 1
      mriord(3) = 2
      mriord(4) = 2
      mriord(5) = 0
      mriord(6) = 0
      mriord(7) = 0
      mriord(8) = 0
c
c     Units for the geometries in the esp.fu71 to esp.fu78 input files
c 
      do i=1,8
         mriufi(i) = 3
      enddo
c
      return
      end
